opticalglass
------------

Tools for reading commercial optical glass catalogs
===================================================

This package is a set of python scripts for reading the excel spreadsheets published by optical glass manufacturers.

The package currently supports the following manufacturers:

    * CDGM
    * Hoya
    * Ohara
    * Schott

.. note::

All rights and ownership of the data is retained by the original owners, i.e the respective manufacturers.
